@@ -4,7 +4,7 @@ use Dancer qw/:syntax :script/;
 use Dancer::Plugin::DBIC 'schema';
 
 use App::Netdisco::Util::PortMAC 'get_port_macs';
-use App::Netdisco::Util::SanityCheck 'check_mac';
+use App::Netdisco::Util::Node 'check_mac';
 use App::Netdisco::Util::SNMP 'snmp_comm_reindex';
 use Time::HiRes 'gettimeofday';
 
@@ -36,7 +36,7 @@ Given a Device database object, and a working SNMP connection, connect to a
 device and discover the MAC addresses listed against each physical port
 without a neighbor.
 
-If the device has VLANs, C<do_macsuck> will walk each VALN to get the MAC
+If the device has VLANs, C<do_macsuck> will walk each VLAN to get the MAC
 addresses from there.
 
 It will also gather wireless client information if C<store_wireless_clients>
@@ -124,7 +124,7 @@ sub do_macsuck {
     time_last => { '<' => \$now },
   })->update({ active => \'false' });
 
-  debug sprintf ' [%s] macsuck - removed %s fwd table entries to archive',
+  debug sprintf ' [%s] macsuck - removed %d fwd table entries to archive',
     $ip, $archived;
 
   $device->update({last_macsuck => \$now});
@@ -151,14 +151,13 @@ sub store_node {
   schema('netdisco')->txn_do(sub {
     my $nodes = schema('netdisco')->resultset('Node');
 
-    # TODO: probably needs changing if we're to support VTP domains
     my $old = $nodes->search(
         { mac   => $mac,
+          vlan   => $vlan,
           -bool => 'active',
           -not  => {
                     switch => $ip,
                     port   => $port,
-                    vlan   => $vlan,
                   },
         })->update( { active => \'false' } );
 
